@@ -3,9 +3,9 @@
 from __future__ import absolute_import
 
 from datetime import datetime
-from time import time
 from functools import lru_cache
 from json.decoder import JSONDecodeError
+from time import time
 from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Union, cast
 
 import requests
@@ -660,6 +660,16 @@ class EvergreenApi(object):
         url = self._create_url("/tasks/{task_id}/tests".format(task_id=task_id))
         return [Tst(test, self) for test in self._paginate(url, params)]  # type: ignore[arg-type]
 
+    def manifest_for_task(self, task_id: str) -> Manifest:
+        """
+        Get the manifest for the given task.
+
+        :param task_id: Task Id fo query.
+        :return: Manifest for the given task.
+        """
+        url = self._create_url(f"/tasks/{task_id}/manifest")
+        return Manifest(self._call_api(url).json(), self)  # type: ignore[arg-type]
+
     def performance_results_by_task(self, task_id: str) -> PerformanceData:
         """
         Get the 'perf.json' performance results for a given task_id.
@@ -860,7 +870,9 @@ class RetryingEvergreenApi(EvergreenApi):
         super(RetryingEvergreenApi, self).__init__(api_server, auth, timeout)
 
     @retry(
-        retry=retry_if_exception_type(requests.exceptions.HTTPError),
+        retry=retry_if_exception_type(
+            (requests.exceptions.HTTPError, requests.exceptions.ConnectionError,)
+        ),
         stop=stop_after_attempt(MAX_RETRIES),
         wait=wait_exponential(multiplier=1, min=START_WAIT_TIME_SEC, max=MAX_WAIT_TIME_SEC),
         reraise=True,
