@@ -4,9 +4,10 @@ from __future__ import absolute_import
 
 from datetime import timedelta
 from enum import IntEnum
-from typing import Any, Callable, Dict, Iterable, List, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Optional
 
 from evergreen.base import _BaseEvergreenObject, evg_attrib, evg_datetime_attrib
+from evergreen.manifest import Manifest
 
 if TYPE_CHECKING:
     from evergreen.api import EvergreenApi
@@ -316,6 +317,10 @@ class Task(_BaseEvergreenObject):
 
         return None
 
+    def get_manifest(self) -> Manifest:
+        """Get the Manifest for this task."""
+        return self._api.manifest_for_task(self.task_id)
+
     def __repr__(self) -> str:
         """
         Get a string representation of Task for debugging purposes.
